==> haskell-generic-random-1.5.0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-EbLfnWlvIbo2LZPc9ZBJTW
key:                  generic-random-1.5.0.1-EbLfnWlvIbo2LZPc9ZBJTW
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  edbb5d4daef772e59ee7cdf89ff28f70
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.0.2/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/generic-random-1.5.0.1
hs-libraries:         HSgeneric-random-1.5.0.1-EbLfnWlvIbo2LZPc9ZBJTW
depends:
    QuickCheck-2.14.2-D5HxM6rZiMl2ZRyF0sxRxv base-4.15.1.0

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-random-1.5.0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-KUqFERfpahR7eVJiamMiV0
key:                  generic-random-1.5.0.1-KUqFERfpahR7eVJiamMiV0
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  fae91fcf6869f4650a511cc738aca3dd
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.0.2/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/generic-random-1.5.0.1
hs-libraries:         HSgeneric-random-1.5.0.1-KUqFERfpahR7eVJiamMiV0
depends:
    QuickCheck-2.14.2-1ypjvWj62Tv8anPe2Haych base-4.15.1.0

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
